;+
; NAME:
;  astcol
; PURPOSE:
;  Collect astrometry observations for multiple objects
; DESCRIPTION:
;  
; CATEGORY:
;  Astrometry
; CALLING SEQUENCE:
;  astcol,OBSCODE=obscode
;
; INPUTS:
;
; OPTIONAL INPUT PARAMETERS:
;
; KEYWORD INPUT PARAMETERS:
;  OBSCODE - Observatory code for observations, default=688 (Lowell Obs.)
;
; OUTPUTS:
;
; KEYWORD OUTPUT PARAMETERS:
;
; COMMON BLOCKS:
;
; SIDE EFFECTS:
;
; RESTRICTIONS:
;
; PROCEDURE:
;
; MODIFICATION HISTORY:
;    97/03/18 - Written by Marc W. Buie, Lowell Observatory
;-
PRO astcol,OBSCODE=obscode

   if badpar(obscode,[0,1,2,3],0,CALLER='ASTCOL: (OBSCODE) ',default=688) then return

   ; Get current directory, this will identify the date of observation.
   cd,'.',current=cdir
   pos=rstrpos(cdir,'/')
   date = strmid(cdir,pos+1,99)

   spawn,'ls *.ast',filelist
   nfiles=n_elements(filelist)

   IF nfiles eq 0 THEN BEGIN
      print,'No astrometry files to collect.  Aborting.'
      return
   ENDIF

   line=''
   blanks='                   '

   outast = '/gryll/data1/buie/astrometry/'+date+'.ast'
   outted = '/gryll/data1/buie/astrometry/'+date+'.ted'

   openw,last,outast,/get_lun
   openw,lted,outted,/get_lun

   nobs=0
   FOR i=0,nfiles-1 DO BEGIN
      obj=str_sep(filelist(i),'.')
      obj=obj(0)
      IF strmid(obj,0,1) eq 'a' THEN obj=strmid(obj,1,99)
      obj=strupcase(obj)
      openr,lun,filelist(i),/get_lun
      WHILE not eof(lun) DO BEGIN
         readf,lun,line,format='(a)'
         words=str_sep(line,' ')
         jd=double(words(1))
         ras=repchar(words(2),':')
         decs=repchar(words(3),':')
         caldat,jd,year,month,day,hour,minute,second
         day=float(day)+(float(hour)+(float(minute)+float(second)/60.0)/60.0)/24.0
         printf,lted,year,month,day,ras,decs,words(4),obj+blanks,obscode, $
            format='(i4,1x,i2.2,2x,f08.5,2x,a,2x,a,1x,a5,"R ",a9,1x,i3)'
         printf,last,line,' ',strtrim(string(obscode),2),' ',obj
         nobs=nobs+1
      ENDWHILE
      free_lun,lun
   ENDFOR

   free_lun,last,lted

   print,'Astrometry saved: ',date,', ',strtrim(string(nfiles),2), $
         ' objects and ',strtrim(string(nobs),2),' measurements.'

END
