;+
; NAME:
;  ephcheck
; PURPOSE:
;  Compare a set of astrometry observations against an ephemeris.
; DESCRIPTION:
;
; CATEGORY:
;  Astrometry
; CALLING SEQUENCE:
;  ephcheck,objcode,obs,astfile
; INPUTS:
;
; OPTIONAL INPUT PARAMETERS:
;
; KEYWORD INPUT PARAMETERS:
;
; OUTPUTS:
;
; KEYWORD OUTPUT PARAMETERS:
;
; COMMON BLOCKS:
;
; SIDE EFFECTS:
;
; RESTRICTIONS:
;
; PROCEDURE:
;
; MODIFICATION HISTORY:
;
;-
PRO ephcheck,objcode,obs,astfile
   openr,lun,astfile,/get_lun
   nlines=0
   line=''
   WHILE not eof(lun) DO BEGIN
      readf,lun,line,format='(a)'
      nlines=nlines+1
   ENDWHILE
   point_lun,lun,0

   jd=dblarr(nlines)
   raobs=dblarr(nlines)
   decobs=dblarr(nlines)
   fn=strarr(nlines)

   FOR i=0,nlines-1 DO BEGIN
      readf,lun,line,format='(a)'
      words=str_sep(line,' ')
      jd0=double(words(1))
      raf=double(str_sep(words(2),':'))
      decsign=words(3)
      words(3)=strmid(decsign,1,99)
      decsign=strmid(decsign,0,1) ne '-'
      if decsign then decsign = 1 else decsign = -1
      decf=double(str_sep(words(3),':'))
      hmstorad,raf(0),raf(1),raf(2),raobs0
      dmstorad,decsign,decf(0),decf(1),decf(2),decobs0

      jd(i)=jd0
      raobs(i)=raobs0
      decobs(i)=decobs0
      fn(i)=words(0)
   ENDFOR
   free_lun,lun

   ; Generate the ephemeris
   ephem,jd,obs,2+50,objcode,eph
   err=angsep(raobs,decobs,eph(0,*),eph(1,*))*!radeg*3600.0
   merr=mean(err)

   ; Compute total motion from first to last point.
   hmotobj=angsep(raobs(0),decobs(0),raobs(nlines-1),decobs(nlines-1)) $
        / ((jd(nlines-1)-jd(0)) * 24.0 ) * !radeg * 3600.0
   hmoteph=angsep(eph(0,0),eph(1,0),eph(0,nlines-1),eph(1,nlines-1)) $
        / ((jd(nlines-1)-jd(0)) * 24.0 ) * !radeg * 3600.0

   ; Compute direction of motion using first and last points.
   objdir = atan(decobs(nlines-1)-decobs(0),raobs(0)-raobs(nlines-1))*!radeg
   ephdir = atan(eph(1,nlines-1) -eph(1,0), eph(0,0)-eph(0,nlines-1))*!radeg

   FOR i=0,nlines-1 DO BEGIN
      jdstr,jd(i),0,str1
      print,fn(i),' ',str1,' ',err(i),err(i)-merr
   ENDFOR

   print,'Angular motion rate Eph= ',hmoteph,' Obj= ',hmotobj,'  arcsec/hr', $
         format='(a,f6.1,a,f6.1,a)'
   print,'Motion direction    Eph= ',fix(ephdir+0.5), ' Obj= ',fix(objdir+0.5), '  degrees EofN', $
         format='(a,i4,2x,a,i4,2x,a)'
END
