;+
; NAME:
;	interp
; PURPOSE: (one line)
;	One dimensional interpolation onto a new x grid (both irregular)
; DESCRIPTION:
; CATEGORY:
;	Mathematical
; CALLING SEQUENCE:
;	interp,x1,y1,e1,x2,y2,e2
; INPUTS:
;	x1 - Input X array.
;	y1 - Matching input Y array.
;	e1 - Array of uncertainties for Y.
;	x2 - New X array to interpolate Y to.
; OPTIONAL INPUT PARAMETERS:
; KEYWORD PARAMETERS:
; OUTPUTS:
;	y2 - Interpolated values of y1 that match the x2 array.
;	e2 - Array of uncertainties for interpolated values.
; COMMON BLOCKS:
; SIDE EFFECTS:
; RESTRICTIONS:
; PROCEDURE:
; MODIFICATION HISTORY:
;	Written by Marc W. Buie, Lowell Observatory, 1992 Sep 28.
;    5/19/93, DWL, Modified the uncertainty computation.  For each
; interpolation point, uncertainties are calculated using the left and the
; right uncertainties.  The minimum of these becomes the final uncertainty.
;-
pro interp,x1,y1,e1,x2,y2,e2

   if badpar(x1,[1,2,3,4,5],  1,caller='INTERP: (x1) ',npts=n1) then return
   if badpar(y1,[1,2,3,4,5],  1,caller='INTERP: (y1) ',npts=n2) then return
   if badpar(e1,[1,2,3,4,5],  1,caller='INTERP: (e1) ',npts=n3) then return
   if badpar(x2,[1,2,3,4,5],  1,caller='INTERP: (x2) ') then return

   if (min([n1,n2,n3]) ne max([n1,n2,n3])) then begin
      print,'ITERP: x1, y1, and e1 must all be the same length!'
      return
   endif

   if n1 eq 1 then begin
      print,'INTERP: x1, y1, and e1 must have more than one element!'
      return
   endif

   y2=x2*0.
   e2=y2

   for i=0,n_elements(x2)-1 do begin
      l = max(where(x1 le x2(i)))
      r = min(where(x1 gt x2(i)))
      if l eq -1 then l=0
      if r eq -1 then r=n_elements(x1)-1
      if l eq r then begin
         if r eq 0 then r = 1
         if l eq n_elements(x1)-1 then l = r - 1
      endif
      xc=(x2(i)-x1(l))/(x1(r)-x1(l))
      y2(i) = y1(l) + (y1(r)-y1(l))*xc
      e2a = sqrt(e1(l)^2 + (e1(r)^2+e1(l)^2)*xc^2)
      e2b = sqrt(e1(r)^2 + (e1(r)^2+e1(l)^2)*(1-xc)^2)
      e2(i) = min([e2a,e2b])
   end

end
