;+
; NAME: 
;  mkdark
; PURPOSE: 
;  Collect and combine CCD dark frames into a superdark frame
; DESCRIPTION:
; CATEGORY:
;  CCD data processing
; CALLING SEQUENCE:
;  mkdark,root,outsuf,start,nframes,bias,dark
; INPUTS:
; OPTIONAL INPUT PARAMETERS:
; KEYWORD INPUT PARAMETERS:
; OUTPUTS:
; KEYWORD OUTPUT PARAMETERS:
; COMMON BLOCKS:
; SIDE EFFECTS:
; RESTRICTIONS:
; PROCEDURE:
; MODIFICATION HISTORY:
;  95/03/09 - Initial crude version written, Marc W. Buie, Lowell Observatory
;  95/08/30, MWB, added OVERSCAN and CROP keywords
;  95/11/22, MWB, add EXCLUDE keyword
;-
pro mkdark,root,outsuf,start,nframes,bias,dark, $
       OVERSCAN=overscan,CROP=crop,EXCLUDE=exclude

on_error,2

if badpar(root,    7,        0,caller='MKDARK: (root) '    ) then return
if badpar(outsuf,  7,        0,caller='MKDARK: (outsuf) '  ) then return
if badpar(start,   [2,3],    0,caller='MKDARK: (start) '   ) then return
if badpar(nframes, [2,3],    0,caller='MKDARK: (nframes) ' ) then return
if badpar(bias,    [2,3,4,5],2,caller='MKDARK: (bias) '    ) then return
if badpar(overscan,[0,2,3],  1,caller='MKDARK: (overscan) ') then return
if badpar(exclude,[0,2,3],[0,1],caller='MKDARK: (exclude) ',default=-1) then return
if badpar(crop,    [0,2,3],  1,caller='MKDARK: (crop) '    ) then return

frames=start+indgen(nframes)
print,'Load frames ',start,' to ',start+nframes-1
for i=0,nframes-1 do begin
   z=where(frames(i) eq exclude,count)
   if count ne 0 then frames(i)=-1
endfor
z=where(frames ne -1,count)
if count eq 0 then $
   message,'Error ** you have excluded all frames, nothing to do.'

fname=root+string(frames(z(0)),format='(i3.3)')
first = readfits(fname,hdr,/silent)
exptime=sxpar(hdr,'EXPTIME')
sz=size(first)
firstframe=frames(z(0))

if keyword_set(overscan) and keyword_set(crop) then begin
   firstn = colbias(first,overscan(0),overscan(1), $
               crop(0),crop(1),crop(2),crop(3),biasval=biasval)
   sz=size(firstn)
   cube=fltarr(sz(1),sz(2),count,/nozero)
   cube(*,*,0)=(firstn-bias)/float(exptime)
   print,fname,exptime,biasval
   j=1
   for i=1,nframes-1 do begin
      if frames(i) ne -1 and frames(i) ne firstframe then begin
         fname=root+string(frames(i),format='(i3.3)')
         frame = readfits(fname,hdr,/silent)
         exptime=sxpar(hdr,'EXPTIME')
         cube(*,*,j) = (colbias(frame,overscan(0),overscan(1), $
                           crop(0),crop(1),crop(2),crop(3), $
                           biasval=biasval) - $
                                   bias ) / float(exptime)
         print,fname,exptime,biasval
         j=j+1
      endif
   endfor
endif else if keyword_set(overscan) then begin
   firstn = colbias(first,overscan(0),overscan(1),biasval=biasval)
   sz=size(firstn)
   cube=fltarr(sz(1),sz(2),count,/nozero)
   cube(*,*,0)=(firstn-bias)/float(exptime)
   print,fname,exptime,biasval
   j=1
   for i=1,nframes-1 do begin
      if frames(i) ne -1 and frames(i) ne firstframe then begin
         fname=root+string(frames(i),format='(i3.3)')
         frame = readfits(fname,hdr,/silent)
         exptime=sxpar(hdr,'EXPTIME')
         cube(*,*,j) = (colbias(frame,overscan(0),overscan(1),biasval=biasval) - $
                                 bias ) / float(exptime)
         print,fname,exptime,biasval
         j=j+1
      endif
   endfor
endif else if keyword_set(crop) then begin
   firstn = first(crop(0):crop(1),crop(2):crop(3))
   sz=size(firstn)
   cube=fltarr(sz(1),sz(2),count,/nozero)
   cube(*,*,0)=(firstn-bias)/float(exptime)
   print,fname,exptime
   j=1
   for i=1,nframes-1 do begin
      if frames(i) ne -1 and frames(i) ne firstframe then begin
         fname=root+string(frames(i),format='(i3.3)')
         frame = readfits(fname,hdr,/silent)
         exptime=sxpar(hdr,'EXPTIME')
         cube(*,*,j) = (frame(crop(0):crop(1),crop(2):crop(3))-bias)/float(exptime)
         print,fname,exptime
         j=j+1
      endif
   endfor
endif else begin
   cube=fltarr(sz(1),sz(2),count,/nozero)
   cube(*,*,0)=(first-bias)/float(exptime)
   print,fname,exptime
   j=1
   for i=1,nframes-1 do begin
      if frames(i) ne -1 and frames(i) ne firstframe then begin
         fname=root+string(frames(i),format='(i3.3)')
         cube(*,*,j) = readfits(fname,hdr,/silent)-bias
         exptime=sxpar(hdr,'EXPTIME')
         cube(*,*,j) = cube(*,*,j) / float(exptime)
         print,fname,exptime
         j=j+1
      endif
   endfor
endelse

avgclip,cube,dark
writefits,root+outsuf,dark,hdr
print,'Saving final dark frame to ',root+outsuf

end
