;+
; NAME: 
;  mkflat
; PURPOSE: 
;  Collect and combine CCD flat frames into a superflat frame
; DESCRIPTION:
; CATEGORY:
;  CCD data processing
; CALLING SEQUENCE:
;  mkflat,root,outsuf,start,nframes,bias,dark,flat
; INPUTS:
; OPTIONAL INPUT PARAMETERS:
; KEYWORD INPUT PARAMETERS:
; OUTPUTS:
; KEYWORD OUTPUT PARAMETERS:
; COMMON BLOCKS:
; SIDE EFFECTS:
; RESTRICTIONS:
; PROCEDURE:
; MODIFICATION HISTORY:
;  95/03/10 - Initial crude version written, Marc W. Buie, Lowell Observatory
;  95/06/04, MWB, added EXCLUDE keyword
;  95/06/13, MWB, added SCALE, OVERSCAN, CROP keywords
;-
pro mkflat,root,outsuf,start,nframes,bias,dark,flat, $
   EXCLUDE=exclude,SCALE=scale, $
   OVERSCAN=overscan,CROP=crop

if badpar(root,   7,    0,caller='MKFLAT: (root) '   ) then return
if badpar(outsuf, 7,    0,caller='MKFLAT: (outsuf) ' ) then return
if badpar(start,  [2,3],0,caller='MKFLAT: (start) '  ) then return
if badpar(nframes,[2,3],0,caller='MKFLAT: (nframes) ') then return
if badpar(bias,   [2,3,4,5],2,caller='MKFLAT: (bias) ') then return
if badpar(dark,   [2,3,4,5],[0,2],caller='MKFLAT: (dark) ') then return
if badpar(exclude,[0,2,3],[0,1],caller='MKFLAT: (exclude) ',default=-1) then return
if badpar(scale,[0,2,3],[0,1],caller='MKFLAT: (scale) ',default=[46,302,150,426]) then return

frames=start+indgen(nframes)
print,'Load frames ',start,' to ',start+nframes-1
for i=0,nframes-1 do begin
   z=where(frames(i) eq exclude,count)
   if count ne 0 then frames(i)=-1
endfor
z=where(frames ne -1,count)
if count eq 0 then $
   message,'Error ** you have excluded all frames, nothing to do.'

hdr = headfits(root+string(frames(z(0)),format='(i3.3)'))
xdim=sxpar(hdr,'NAXIS1')
ydim=sxpar(hdr,'NAXIS2')

if keyword_set(crop) then begin
   xdim = crop(1)-crop(0)+1
   ydim = crop(3)-crop(2)+1
endif

cube=fltarr(xdim,ydim,count,/nozero)
j=0
for i=0,nframes-1 do begin
   if frames(i) ne -1 then begin
	   fname = root+string(frames(i),format='(i3.3)')
	   print,'Loading frame ',i,'  ',fname
      if keyword_set(crop) and keyword_set(overscan) then begin
   	   new = readfits(fname,/silent)
         cube(*,*,j) = colbias(new,overscan(0),overscan(1),crop(0),crop(1),crop(2),crop(3))-bias
      endif else if keyword_set(crop) then begin
   	   new = readfits(fname,/silent)
         cube(*,*,j) = new(crop(0):crop(1),crop(2):crop(3))-bias
      endif else if keyword_set(overscan) then begin
   	   new = readfits(fname,/silent)
         cube(*,*,j) = colbias(new,overscan(0),overscan(1))-bias
      endif else begin
   	   cube(*,*,j) = readfits(fname,/silent)-bias
      endelse
	   exptime=float(sxpar(hdr,'EXPTIME'))
	   cube(*,*,j) = cube(*,*,j) - dark*exptime
      j=j+1
   endif
endfor

avgclip,cube,flat,scale=scale,/norm
sxaddpar,hdr,'BZERO',0.0
sxaddpar,hdr,'BSCALE',1.0
writefits,root+outsuf,flat,hdr
print,'Saving final flat frame to ',root+outsuf

end
