;+
; NAME:
;  refnet
; PURPOSE:
;  Support routine for calling ``REFNET'' to get stars from USNO A1.0 catalog.
; DESCRIPTION:
;
; CATEGORY:
;  Astrometry
;
; CALLING SEQUENCE:
;  refnet,ra,dec,width,height,bmaglim,rmaglim,starfile
;
; INPUTS:
;  ra      - Right ascension of center of field for extraction (J2000, radians).
;  dec     - Declination of center of field for extraction (J2000, radians).
;  width   - Width of field to extract (arcsec).
;  height  - Height of field to extract (arcsec).
;  bmaglim - Limiting Blue magnitude to extract.
;  rmaglim - Limiting Red magnitude to extract.
;  starfile- File name for the results of the catalog extraction.
;
; OPTIONAL INPUT PARAMETERS:
;
; KEYWORD INPUT PARAMETERS:
;
; OUTPUTS:
;  The output is all to the file and contains a list of stars from the
;    USNO A1.0 catalog according to the input constraints.
;
; KEYWORD OUTPUT PARAMETERS:
;
; COMMON BLOCKS:
;
; SIDE EFFECTS:
;
; RESTRICTIONS:
;  Currently this is rather restricted and is just an initial working version.
;  This is hardcoded to a specific location for the catalog and executable.
;  This program will work only on Unix platforms at present.
;
; PROCEDURE:
;
; MODIFICATION HISTORY:
;  97/05/08, Written by Marc W. Buie, Lowell Observatory
;
;-
PRO refnet,ra,dec,width,height,bmaglim,rmaglim,starfile
   rastr,ra,3,ras
   decstr,dec,2,decs
   ras=repchar(ras,':',' ')
   decs=repchar(decs,':',' ')
   openw,lun,'tmp.xxx',/get_lun
   printf,lun,ras,decs,float(width),float(height), $
      float(bmaglim),float(rmaglim), $
      format='(a,1x,a,1x,i5,1x,i5,1x,"-5.0 ",f4.1," -5.0 ",f4.1," -10.0 10.0 100000.0")'
   free_lun,lun
   spawn,'/pub/home/koehn/starnet/dist/refnet -pr b -ah out ' + $
         '-cm /pub/home/koehn/starnet/dist/USNO-A1.0 -in tmp.xxx > '+ $
         starfile
   spawn,'rm tmp.xxx'
END
